package net.sf.logdistiller;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.*;
import java.util.*;

public class PublishHelper
{
    private final LogDistillation ld;

    private final List publishers;

    public PublishHelper( LogDistillation ld )
    {
        this( ld, new ArrayList() );
    }

    public PublishHelper( LogDistillation ld, List publishers )
    {
        this.ld = ld;
        this.publishers = publishers;
    }

    public int publish()
        throws IOException, Publisher.PublishException
    {
        int published = publishGlobal();

        LogDistillation.Group[] groups = ld.getGroups();
        int count = groups.length;
        for ( int i = 0; i < count; i++ )
        {
            LogDistillation.Group group = groups[i];
            if ( ( !group.isSkip() ) && ( group.getEventCount() > 0 ) )
            {
                published += publishGroup( group );
            }
        }
        return published;
    }

    public int publishGlobal()
        throws IOException, Publisher.PublishException
    {
        LogDistiller.Report[] reports = ld.getDefinition().getOutput().getReports();
        int count = reports.length;
        int published = 0;
        for ( int i = 0; i < count; i++ )
        {
            LogDistiller.Report report = reports[i];
            Publisher publisher = Publishers.getPublisher( report.getPublisher() );
            if ( isPublisherEnabled( publisher ) )
            {
                publisher.publish( ld, report );
                published++;
            }
        }
        return published;
    }

    public int publishGroup( LogDistillation.Group group )
        throws IOException, Publisher.PublishException
    {
        LogDistiller.Report[] reports = group.getDefinition().getReports();
        int count = reports.length;
        int published = 0;
        for ( int i = 0; i < count; i++ )
        {
            LogDistiller.Report report = reports[i];
            Publisher publisher = Publishers.getPublisher( report.getPublisher() );
            if ( isPublisherEnabled( publisher ) )
            {
                publisher.publish( group, report );
                published++;
            }
        }
        return published;
    }

    private boolean isPublisherEnabled( Publisher publisher )
    {
        return ( publisher != null ) && ( ( publishers == null ) || publishers.contains( publisher.getId() ) );
    }
}
