package net.sf.logdistiller;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.IOException;
import java.io.Writer;

/**
 * Report formats' base class.
 */
public abstract class ReportFormat
{
    private final String id;

    protected ReportFormat( String id )
    {
        this.id = id;
    }

    public String getId()
    {
        return id;
    }

    public abstract String getContentType();

    public abstract String getFileExtension();

    public abstract void report( LogDistillation ld, Writer output )
        throws IOException;

    public abstract void report( LogDistillation.Group group, Writer output )
        throws IOException;

    protected int addPluginsGroupReport( LogDistillation.Group group, PluginReport report )
    {
        LogDistillation.Plugin[] plugins = group.getPlugins();
        int len = plugins.length;
        int count = 0;
        for ( int i = 0; i < len; i++ )
        {
            LogDistillation.Plugin plugin = plugins[i];
            if ( plugin.getDefinition().isGroupReportEnabled() )
            {
                plugin.appendGroupReport( report );
                count++;
            }
        }
        return count;
    }

    protected int addPluginsGlobalReport( LogDistillation.Group group, PluginReport report )
    {
        LogDistillation.Plugin[] plugins = group.getPlugins();
        int len = plugins.length;
        int count = 0;
        for ( int i = 0; i < len; i++ )
        {
            LogDistillation.Plugin plugin = plugins[i];
            if ( plugin.getDefinition().isGlobalReportEnabled() )
            {
                plugin.appendGlobalReport( report );
                count++;
            }
        }
        return count;
    }

    public static abstract class PluginReport
    {
        public abstract void beginPluginReport( LogDistillation.Plugin plugin, String description );

        public abstract void addLink( String filename, String description );

        public abstract void addParam( String param, String value );

        public abstract void addItem( int count, String description );

        public abstract void endPluginReport();
    }
}
