package net.sf.logdistiller.gui;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.LayoutManager2;
import java.util.HashMap;
import java.util.Map;

import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;

/**
 * This class is a simplified version of FormLayoutMaker's equivalent class, in a dream to avoid need for Java 1.4 at
 * runtime.
 */
public class SimpleContainerLayout
    implements LayoutManager2
{
    private final Map componentConstraints = new HashMap();

    private final Map componentsToNames = new HashMap();

    private final FormLayout formLayout;

    private final String name;

    public SimpleContainerLayout( String name, String columnSpecs, String rowSpecs )
    {
        this.name = name;
        formLayout = new FormLayout( columnSpecs, rowSpecs );
    }

    public String getName()
    {
        return this.name;
    }

    public void addCellConstraints( String name, CellConstraints constraints )
    {
        componentConstraints.put( name, constraints );
    }

    // interface for LayoutManager2
    public void addLayoutComponent( String name, Component comp )
    {
        throw new RuntimeException(
                                    "This method should not be called.  Call addLayoutComponent(Component, Object) instead" );
    }

    public float getLayoutAlignmentX( Container target )
    {
        return formLayout.getLayoutAlignmentX( target );
    }

    public float getLayoutAlignmentY( Container target )
    {
        return formLayout.getLayoutAlignmentY( target );
    }

    public void invalidateLayout( Container target )
    {
        formLayout.invalidateLayout( target );
    }

    public void layoutContainer( Container parent )
    {
        formLayout.layoutContainer( parent );
    }

    public Dimension maximumLayoutSize( Container target )
    {
        return formLayout.maximumLayoutSize( target );
    }

    public Dimension minimumLayoutSize( Container parent )
    {
        return formLayout.minimumLayoutSize( parent );
    }

    public Dimension preferredLayoutSize( Container parent )
    {
        return formLayout.preferredLayoutSize( parent );
    }

    public void removeLayoutComponent( Component comp )
    {
        String componentName = (String) componentsToNames.get( comp );
        componentsToNames.remove( comp );
        componentConstraints.remove( componentName );
        formLayout.removeLayoutComponent( comp );
    }

    public void addLayoutComponent( Component comp, Object constraints )
    {
        String componentName = (String) constraints;
        CellConstraints cellConstraints = (CellConstraints) componentConstraints.get( componentName );
        if ( cellConstraints == null )
        {
            System.err.println( "Warning: " + componentName + " was added without constraints" );
            cellConstraints = new CellConstraints();
            componentConstraints.put( componentName, cellConstraints );
            comp.setVisible( false );
        }
        componentsToNames.put( comp, componentName );
        formLayout.addLayoutComponent( comp, cellConstraints );
    }
}
