package net.sf.logdistiller.publishers;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.*;

import net.sf.logdistiller.*;
import net.sf.logdistiller.LogDistillation.Group;
import net.sf.logdistiller.LogDistiller.Report;

/**
 * An empty publisher, delegating everything to a delegate publisher. The delegate publisher gets instantiated on the
 * first use, then its libraries dependencies are needed only if the publisher is really used, not when the publisher
 * is registered.
 *
 * @since 1.1
 */
public class DelegatePublisher
    extends Publisher
{
    private final String id;

    private final String className;

    private Publisher delegate;

    public DelegatePublisher( String id, String className )
    {
        this.id = id;
        this.className = className;
    }

    public String getId()
    {
        return id;
    }

    protected Publisher getDelegate()
    {
        if ( delegate == null )
        {
            try
            {
                delegate = (Publisher) Class.forName( className ).newInstance();
            }
            catch ( InstantiationException ie )
            {
                throw new RuntimeException( "unable to instantiate " + className, ie );
            }
            catch ( IllegalAccessException iae )
            {
                throw new RuntimeException( "unable to instantiate " + className, iae );
            }
            catch ( ClassNotFoundException cnfe )
            {
                throw new RuntimeException( "unable to instantiate " + className, cnfe );
            }
        }

        return delegate;
    }

    public void publish( LogDistillation logdistillation, LogDistiller.Report report )
        throws IOException, PublishException
    {
        getDelegate().publish( logdistillation, report );
    }

    public void publish( Group group, Report report )
        throws IOException, PublishException
    {
        getDelegate().publish( group, report );
    }
}
