package net.sf.logdistiller.publishers;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.*;

import org.apache.commons.io.IOUtils;

import net.sf.logdistiller.*;

/**
 * Save report of a LogDistillation in a file.
 * <p>
 * Parameters:
 * <ul>
 * <li><code>filename</code> (default: <code>report.[ext]</code> for global report, or
 * <code><i>[group id].[ext]</i></code> for group report): the file name (relative to output directory)
 * </ul>
 */
public class FilePublisher
    extends Publisher
{
    public String getId()
    {
        return "file";
    }

    public void publish( LogDistillation logdistillation, LogDistiller.Report report )
        throws IOException
    {
        ReportFormat format = ReportFormats.getReportFormat( report.getFormat() );
        String filename = report.getParam( "filename", "result." + format.getFileExtension() );
        Writer out = new FileWriter( logdistillation.newDestinationFile( filename ) );
        try
        {
            format.report( logdistillation, out );
        }
        finally
        {
            IOUtils.closeQuietly( out );
        }
    }

    public void publish( LogDistillation.Group group, LogDistiller.Report report )
        throws IOException
    {
        ReportFormat format = ReportFormats.getReportFormat( report.getFormat() );
        String filename = report.getParam( "filename" );
        if ( filename == null )
        {
            filename = group.getDefinition().getId() + "." + format.getFileExtension();
        }
        Writer out = new FileWriter( group.getLogdistillation().newDestinationFile( filename ) );
        try
        {
            format.report( group, out );
        }
        finally
        {
            IOUtils.closeQuietly( out );
        }
    }
}
