package net.sf.logdistiller.util;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.IOException;
import java.net.URL;
import java.util.*;

/**
 * Helper to load extensions for <b>LogDistiller</b>. Extensions are declared in <code>logdistiller.properties</code>
 * resource file, as properties. Each extensible part can be declared as a property which key value specifies the part
 * extended (<code>logtypes</code>, <code>plugins</code>, <code>publishers</code> or <code>reportformats</code>), the
 * value is the full class name (with package) of the extension.
 *
 * @since 0.7
 */
public class ExtensionHelper
{
    private static List extensionProperties;

    public static List findExtensions( String type )
    {
        if ( extensionProperties == null )
        {
            extensionProperties = findExtensions();
        }
        List extensions = new ArrayList();
        Iterator iter = extensionProperties.iterator();
        while ( iter.hasNext() )
        {
            Properties prop = (Properties) iter.next();
            String extension = prop.getProperty( type );
            if ( extension != null )
            {
                extensions.add( extension );
            }
        }
        return extensions;
    }

    private static List findExtensions()
    {
        URL url = null;
        try
        {
            List extensions = new ArrayList();
            Enumeration res = ExtensionHelper.class.getClassLoader().getResources( "logdistiller.properties" );
            while ( res.hasMoreElements() )
            {
                url = (URL) res.nextElement();
                Properties prop = new Properties();
                prop.load( url.openStream() );
                extensions.add( prop );
            }
            return extensions;
        }
        catch ( IOException ioe )
        {
            String msg =
                ( url == null ) ? "unable to list resources logdistiller.properties" : "unable to load resource "
                    + url.toExternalForm();
            throw new RuntimeException( msg, ioe );
        }
    }
}
