package net.sf.logdistiller.util;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.Map;

/**
 * A small utility to replace properties within strings (syntax: <code>${<i>name</i>}</code>).
 */
public class PropertiesReplacer
{
    private final String beginMark;

    private final String endMark;

    private final Map properties;

    public PropertiesReplacer( Map properties, String beginMark, String endMark )
    {
        this.properties = properties;
        this.beginMark = beginMark;
        this.endMark = endMark;
    }

    public PropertiesReplacer( Map properties )
    {
        this( properties, "${", "}" );
    }

    /**
     * Replace <code>${<i>name</i>}</code> by the value of the property.
     *
     * @param source String the string to interpret (or <code>null</code>)
     * @return String the transformed string
     * @throws IllegalArgumentException if the source string references an inexistent property
     */
    public String replaceProperties( String source )
    {
        if ( source == null )
        {
            return null;
        }
        int index = 0;
        int nextBegin, nextEnd;
        StringBuffer buff = new StringBuffer();
        while ( ( ( nextBegin = source.indexOf( beginMark, index ) ) >= 0 )
            && ( ( nextEnd = source.indexOf( endMark, nextBegin ) ) >= 0 ) )
        {
            String name = source.substring( nextBegin + 2, nextEnd );
            String value = (String) properties.get( name );
            if ( value == null )
            {
                throw new IllegalArgumentException( "unknown property '" + name + "'" );
            }
            buff.append( source.substring( index, nextBegin ) );
            buff.append( value );
            index = nextEnd + 1;
        }
        if ( index == 0 )
        {
            // little optimization...
            return source;
        }
        buff.append( source.substring( index ) );
        return buff.toString();
    }
}
