package net.sf.logdistiller.util;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.text.ParseException;

public class StringCutter
{
    private final String src;

    private int index = 0;

    public StringCutter( String src )
    {
        this.src = src;
    }

    public StringCutter( String src, int startIndex )
    {
        this.src = src;
        this.index = startIndex;
    }

    public String parseTo( String delimiter )
        throws ParseException
    {
        return parseTo( delimiter, true );
    }

    public String parseTo( String delimiter, boolean failIfNotFound )
        throws ParseException
    {
        int to = src.indexOf( delimiter, index );
        if ( to < index )
        {
            if ( failIfNotFound )
            {
                throw new ParseException( "delimiter '" + delimiter + "' not found starting from index " + index
                                          + " in '" + src + "'", index );
            }
            String token = src.substring( index );
            index = src.length();
            return token;
        }
        String token = src.substring( index, to );
        index = to + delimiter.length();
        return token;
    }

    public String getRemaining()
    {
        return src.substring( index );
    }
}
